==> mule-munit-support-3.6.2-sources.jar: org/mule/munit/wrapped/MunitDefaultMuleMessage.java <==
/*
 * Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.wrapped;

import org.mule.DefaultMuleMessage;
import org.mule.api.MuleContext;
import org.mule.api.MuleMessage;

import javax.activation.DataHandler;
import java.util.Map;

public class MunitDefaultMuleMessage extends DefaultMuleMessage {
    public MunitDefaultMuleMessage(MuleMessage message) {
        super(message);
    }

    public MunitDefaultMuleMessage(Object message, MuleContext muleContext) {
        super(message, muleContext);
    }

    public MunitDefaultMuleMessage(Object message, Map<String, Object> outboundProperties, MuleContext muleContext) {
        super(message, outboundProperties, muleContext);
    }

    public MunitDefaultMuleMessage(Object message, Map<String, Object> outboundProperties, Map<String, DataHandler> attachments, MuleContext muleContext) {
        super(message, outboundProperties, attachments, muleContext);
    }

    public MunitDefaultMuleMessage(Object message, Map<String, Object> inboundProperties, Map<String, Object> outboundProperties, Map<String, DataHandler> attachments, MuleContext muleContext) {
        super(message, inboundProperties, outboundProperties, attachments, muleContext);
    }

    // TODO: Remove lines: this constructors don't exists in 3.6.x

//    public MunitDefaultMuleMessage(Object message, Map<String, Object> inboundProperties, Map<String, Object> outboundProperties, Map<String, DataHandler> attachments, MuleContext muleContext, DataType dataType) {
//        super(message, inboundProperties, outboundProperties, attachments, muleContext, dataType);
//    }

    public MunitDefaultMuleMessage(Object message, MuleMessage previous, MuleContext muleContext) {
        super(message, previous, muleContext);
    }
}

==> mule-munit-support-3.8.8-20250619.041955-2102-sources.jar: org/mule/munit/wrapped/MunitDefaultMuleMessage.java <==
/*
 * Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.wrapped;

import org.mule.DefaultMuleMessage;
import org.mule.api.MuleContext;
import org.mule.api.MuleMessage;
import org.mule.api.transformer.DataType;

import javax.activation.DataHandler;
import java.util.Map;

public class MunitDefaultMuleMessage extends DefaultMuleMessage {
    public MunitDefaultMuleMessage(MuleMessage message) {
        super(message);
    }

    public MunitDefaultMuleMessage(Object message, MuleContext muleContext) {
        super(message, muleContext);
    }

    public MunitDefaultMuleMessage(Object message, Map<String, Object> outboundProperties, MuleContext muleContext) {
        super(message, outboundProperties, muleContext);
    }

    public MunitDefaultMuleMessage(Object message, Map<String, Object> outboundProperties, Map<String, DataHandler> attachments, MuleContext muleContext) {
        super(message, outboundProperties, attachments, muleContext);
    }

    public MunitDefaultMuleMessage(Object message, Map<String, Object> inboundProperties, Map<String, Object> outboundProperties, Map<String, DataHandler> attachments, MuleContext muleContext) {
        super(message, inboundProperties, outboundProperties, attachments, muleContext);
    }

    public MunitDefaultMuleMessage(Object message, Map<String, Object> inboundProperties, Map<String, Object> outboundProperties, Map<String, DataHandler> attachments, MuleContext muleContext, DataType dataType) {
        super(message, inboundProperties, outboundProperties, attachments, muleContext, dataType);
    }

    public MunitDefaultMuleMessage(Object message, MuleMessage previous, MuleContext muleContext) {
        super(message, previous, muleContext);
    }
}
